| change_playlist_details | R Documentation |
Change a playlist’s name and public/private state. (The user must, of course, own the playlist.)
change_playlist_details(playlist_id, name = NULL, public = NULL,
collaborative = NULL, description = NULL,
authorization = get_spotify_authorization_code())
playlist_id |
Required. The Spotify ID for the playlist. |
name |
Optional String containing the name for the new playlist, for example |
public |
Optional. Boolean. If |
collaborative |
Optional. Boolean. If |
description |
Optional. String containing the playlist description as displayed in Spotify Clients and in the Web API. |
authorization |
Required. A valid access token from the Spotify Accounts service. See the Web API authorization Guide for more details. Defaults to |
No return value. Playlist details changed.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.