| check_users_following | R Documentation |
Check if Users Follow a Playlist
check_users_following(playlist_id, ids,
authorization = get_spotify_authorization_code())
playlist_id |
Required. The Spotify ID of the playlist. |
ids |
Required. Spotify User IDs; the ids of the users that you want to check to see if they follow the playlist. Maximum: 5 ids. |
authorization |
Required. A valid access token from the Spotify Accounts service. See the Web API authorization Guide for more details. |
Returns a list of results containing user following status.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.