| create_playlist | R Documentation |
Create a playlist for a Spotify user. (The playlist will be empty until you add tracks.)
create_playlist(user_id, name, public = TRUE, collaborative = FALSE,
description = NULL,
authorization = get_spotify_authorization_code())
user_id |
Required. The user's Spotify user ID. |
name |
Required. String containing the name for the new playlist, for example |
public |
Optional. Boolean. Defaults to |
collaborative |
Optional. Boolean. Defaults to |
description |
Optional. String containing the playlist description as displayed in Spotify Clients and in the Web API. |
authorization |
Required. A valid access token from the Spotify Accounts service. See the Web API authorization Guide for more details. Defaults to |
Returns a list containing playlist information.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.