get_artist: Get Spotify catalog information for a single artist...

View source: R/artists.R

get_artistR Documentation

Get Spotify catalog information for a single artist identified by their unique Spotify ID.

Description

Get Spotify catalog information for a single artist identified by their unique Spotify ID.

Usage

get_artist(id, authorization = get_spotify_access_token())

Arguments

id

The Spotify ID for the artist.

authorization

Required. A valid access token from the Spotify Accounts service. See the Web API authorization Guide for more details. Defaults to spotifyr::get_spotify_access_token()

Value

Returns a data frame of results containing album data. See https://developer.spotify.com/documentation/web-api for more information.


tinyspotifyr documentation built on June 7, 2026, 5:06 p.m.