get_category_playlists: Get a list of Spotify playlists tagged with a particular...

View source: R/browse.R

get_category_playlistsR Documentation

Get a list of Spotify playlists tagged with a particular category.

Description

Get a list of Spotify playlists tagged with a particular category.

Usage

get_category_playlists(category_id, market = NULL, limit = 20, offset = 0,
                       authorization = get_spotify_access_token(),
                       include_meta_info = FALSE)

Arguments

category_id

Required. The Spotify ID for the category.

market

Optional. A country: an ISO 3166-1 alpha-2 country code.

limit

Optional. The maximum number of items to return. Default: 20. Minimum: 1. Maximum: 50.

offset

Optional. The index of the first item to return. Default: 0 (the first object). Use with limit to get the next set of items.

authorization

Required. A valid access token from the Spotify Accounts service. See the Web API authorization guide for more details. Defaults to spotifyr::get_spotify_access_token()

include_meta_info

Optional. Boolean indicating whether to include full result, with meta information such as "total", and "limit". Defaults to FALSE.

Value

Returns a data frame of results containing category playlists. See https://developer.spotify.com/documentation/web-api for more information.

Examples

## Not run: 
## Get Brazilian party playlists
get_category_playlists('party', country = 'BR')

## End(Not run)

tinyspotifyr documentation built on June 7, 2026, 5:06 p.m.