| get_latest_episode | R Documentation |
Get Spotify uri information for a show's latest episodes identified by their unique Spotify ID.
get_latest_episode(id, market = "US",
authorization = get_spotify_authorization_code())
id |
The Spotify ID for the show. |
market |
Required. |
authorization |
Required. A valid access token from the Spotify Accounts service. See the Web API authorization Guide for more details. Defaults to |
Returns a string containing the latest episode data for a show. See https://developer.spotify.com/documentation/web-api for more information.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.