get_my_currently_playing: Get the object currently being played on the user’s Spotify...

View source: R/player.R

get_my_currently_playingR Documentation

Get the object currently being played on the user’s Spotify account.

Description

Get the object currently being played on the user’s Spotify account.

Usage

get_my_currently_playing(market = NULL,
                         authorization = get_spotify_authorization_code())

Arguments

market

An ISO 3166-1 alpha-2 country code or the string "from_token". Provide this parameter if you want to apply Track Relinking

authorization

Required. A valid access token from the Spotify Accounts service. See the Web API authorization guide for more details. Defaults to spotifyr::get_spotify_access_token(). The access token must have been issued on behalf of the current user.
The access token must have the user-read-currently-playing and/or user-read-playback-state scope authorized in order to read information.

Value

Returns a data frame of results containing user profile information. See https://developer.spotify.com/documentation/web-api for more information.


tinyspotifyr documentation built on June 7, 2026, 5:06 p.m.