get_my_devices: Get information about a user’s available devices.

View source: R/player.R

get_my_devicesR Documentation

Get information about a user’s available devices.

Description

Get information about a user’s available devices.

Usage

get_my_devices(authorization = get_spotify_authorization_code())

Arguments

authorization

Required. A valid access token from the Spotify Accounts service. See the Web API authorization Guide for more details. Defaults to spotifyr::get_spotify_access_token(). The access token must have been issued on behalf of the current user.
The access token must have the user-read-playback-state scope authorized in order to read information.

Value

Returns a data frame of results containing user device information. See the official Spotify Web API documentation for more information.


tinyspotifyr documentation built on June 7, 2026, 5:06 p.m.