| get_my_playlists | R Documentation |
Get a list of the playlists owned or followed by the current Spotify user.
get_my_playlists(limit = 20, offset = 0,
authorization = get_spotify_authorization_code(),
include_meta_info = FALSE)
limit |
Optional. |
offset |
Optional. |
authorization |
Required. A valid access token from the Spotify Accounts service. See the Web API authorization Guide for more details. Defaults to |
include_meta_info |
Optional. Boolean indicating whether to include full result, with meta information such as |
Returns a data frame of results containing user profile information. See https://developer.spotify.com/documentation/web-api for more information.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.