get_my_profile: Get detailed profile information about the current user...

View source: R/users_profile.R

get_my_profileR Documentation

Get detailed profile information about the current user (including the current user’s username).

Description

Get detailed profile information about the current user (including the current user’s username).

Usage

get_my_profile(authorization = get_spotify_authorization_code())

Arguments

authorization

Required. A valid access token from the Spotify Accounts service. See the Web API authorization Guide for more details. Defaults to spotifyr::get_spotify_authorization_code(). The access token must have been issued on behalf of the current user.
Reading the user’s email address requires the user-read-email scope; reading country and product subscription level requires the user-read-private scope. See Using Scopes.

Value

Returns a data frame of results containing user profile information. See https://developer.spotify.com/documentation/web-api for more information.


tinyspotifyr documentation built on June 7, 2026, 5:06 p.m.