Get the current user’s top artists or tracks based on calculated affinity.
get_my_top_artists_or_tracks(type = NULL, limit = 20, offset = 0,
time_range = "medium_term",
authorization = get_spotify_authorization_code(),
include_meta_info = FALSE)Returns a data frame of results containing track or album data. See the official API documentation for more information.
Required. The type of entity to return. Valid values: artists or tracks.
Optional.
Maximum number of results to return.
Default: 20
Minimum: 1
Maximum: 50
Optional.
The index of the first entity to return.
Default: 0 (i.e., the first track).
Use with limit to get the next set of entities.
Optional. Over what time frame the affinities are computed. Valid values: long_term (calculated from several years of data and including all new data as it becomes available), medium_term (approximately last 6 months), short_term (approximately last 4 weeks). Default: medium_term.
Required. A valid access token from the Spotify Accounts service. See the Web API authorization Guide for more details. Defaults to spotifyr::get_spotify_access_token()
Optional. Boolean indicating whether to include full result, with meta information such as "total", and "limit". Defaults to FALSE.