Get a list of new album releases featured in Spotify (shown, for example, on a Spotify player’s “Browse” tab).
get_new_releases(country = NULL, limit = 20, offset = 0,
authorization = get_spotify_access_token(),
include_meta_info = FALSE)Returns a data frame of results containing new releases. See https://developer.spotify.com/documentation/web-api for more information.
Optional. A country: an ISO 3166-1 alpha-2 country code. Provide this parameter if you want the list of returned items to be relevant to a particular country. If omitted, the returned items will be relevant to all countries.
Optional. The maximum number of items to return. Default: 20. Minimum: 1. Maximum: 50.
Optional. The index of the first item to return. Default: 0 (the first object). Use with limit to get the next set of items.
Required. A valid access token from the Spotify Accounts service. See the Web API authorization guide for more details. Defaults to spotifyr::get_spotify_access_token()
Optional. Boolean indicating whether to include full result, with meta information such as "country", "offset", and "limit". Defaults to FALSE.
if (FALSE) {
## Get new Swedish music
get_new_releases(country = 'SE')
}
Run the code above in your browser using DataLab