Get Spotify catalog information for a single show identified by their unique Spotify ID.
get_show(id, market = "US", authorization = get_spotify_access_token())Returns a data frame of results containing show data. See https://developer.spotify.com/documentation/web-api for more information.
The Spotify ID for the show.
Required.
An ISO 3166-1 alpha-2 country code or the string "from_token".
Supply this parameter to limit the response to one particular geographical market. For example, for albums available in Sweden: market = "SE".
If not given, results will be returned for all markets and you are likely to get duplicate results per album, one for each market in which the album is available!
Required. A valid access token from the Spotify Accounts service. See the Web API authorization Guide for more details. Defaults to spotifyr::get_spotify_access_token()