get_track_audio_features: Get audio feature information for a single track identified...

View source: R/tracks.R

get_track_audio_featuresR Documentation

Get audio feature information for a single track identified by its unique Spotify ID.

Description

Get audio feature information for a single track identified by its unique Spotify ID.

Usage

get_track_audio_features(ids, authorization = get_spotify_access_token())

Arguments

ids

Required. A comma-separated list of the Spotify IDs of the tracks. Maximum: 100 IDs.

authorization

Required. A valid access token from the Spotify Accounts service. See the Web API authorization guide for more details. Defaults to spotifyr::get_spotify_access_token()

Details

Deprecated. Spotify restricted GET /v1/audio-features (HTTP 403) in November 2024; it no longer returns data for apps without prior access.

Value

Returns a data frame of results containing track audio features data. See https://developer.spotify.com/documentation/web-api for more information.


tinyspotifyr documentation built on June 7, 2026, 5:06 p.m.