get_user_profile: Get public profile information about a Spotify user.

View source: R/users_profile.R

get_user_profileR Documentation

Get public profile information about a Spotify user.

Description

Get public profile information about a Spotify user.

Usage

get_user_profile(user_id, authorization = get_spotify_access_token())

Arguments

user_id

Required. The user's Spotify user ID.

authorization

Required. A valid access token from the Spotify Accounts service. See the Web API authorization guide for more details. Defaults to spotifyr::get_spotify_access_token()

Value

Returns a data frame of results containing user profile information. See https://developer.spotify.com/documentation/web-api for more information.


tinyspotifyr documentation built on June 7, 2026, 5:06 p.m.