is_uri: Check if a string matches the pattern of a Spotify URI

View source: R/utils.R

is_uriR Documentation

Check if a string matches the pattern of a Spotify URI

Description

Check if a string matches the pattern of a Spotify URI

Usage

is_uri(s)

Arguments

s

String to check

Value

Returns a boolean.


tinyspotifyr documentation built on June 7, 2026, 5:06 p.m.