| pause_my_playback | R Documentation |
Pause playback on the user’s account.
pause_my_playback(device_id = NULL,
authorization = get_spotify_authorization_code())
device_id |
Optional. The id of the device this command is targeting. If not supplied, the user’s currently active device is the target. |
authorization |
Required. A valid access token from the Spotify Accounts service. See the Web API authorization Guide for more details. Defaults to |
No return value.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.