Learn R Programming

tinyspotifyr (version 0.2.3)

remove_tracks_from_playlist: Remove one or more tracks from a user’s playlist.

Description

Remove one or more tracks from a user’s playlist.

Usage

remove_tracks_from_playlist(playlist_id, uris,
                            authorization = get_spotify_authorization_code())

Value

No return value. Tracks are removed from playlist.

Arguments

playlist_id

Required. The Spotify ID for the playlist.

uris

Optional. A character vector of Spotify track URIs to add. For example
uris = "spotify:track:4iV5W9uYEdYUVa79Axb7Rh", "spotify:track:1301WleyT98MSxVHPZCA6M"
A maximum of 100 tracks can be removed in one request.

authorization

Required. A valid access token from the Spotify Accounts service. See the Web API authorization Guide for more details. Defaults to spotifyr::get_spotify_authorization_code(). The access token must have been issued on behalf of the current user.
Removing tracks to the current user’s public playlists requires authorization of the playlist-modify-public scope; removing tracks from the current user’s private playlist (including collaborative playlists) requires the playlist-modify-private scope. See Using Scopes.