reorder_replace_playlist_items: Reorder or replace one or more items from a user’s playlist.

View source: R/playlists.R

reorder_replace_playlist_itemsR Documentation

Reorder or replace one or more items from a user’s playlist.

Description

Reorder or replace one or more items from a user’s playlist.

Usage

reorder_replace_playlist_items(playlist_id, uris,
                               authorization = get_spotify_authorization_code())

Arguments

playlist_id

Required. The Spotify ID for the playlist.

uris

Optional. A character vector of Spotify track URIs to add. For example
uris = "spotify:track:4iV5W9uYEdYUVa79Axb7Rh", "spotify:track:1301WleyT98MSxVHPZCA6M"
A maximum of 100 tracks can be removed in one request.

authorization

Required. A valid access token from the Spotify Accounts service. See the Web API authorization Guide for more details. Defaults to spotifyr::get_spotify_authorization_code(). The access token must have been issued on behalf of the current user.
Removing tracks to the current user’s public playlists requires authorization of the playlist-modify-public scope; removing tracks from the current user’s private playlist (including collaborative playlists) requires the playlist-modify-private scope. See Using Scopes.

Value

No return value. Tracks are added or reordered on playlist.


tinyspotifyr documentation built on June 7, 2026, 5:06 p.m.