| search_spotify | R Documentation |
Get Spotify Catalog information about artists, albums, tracks or playlists that match a keyword string. For more information see the official documentation.
search_spotify(q, type = c("album", "artist", "playlist", "track"),
market = NULL, limit = 20, offset = 0, include_external = NULL,
authorization = get_spotify_access_token(),
include_meta_info = FALSE)
q |
Required. |
type |
A character vector of item types to search across. |
market |
Optional. |
limit |
Optional. |
offset |
Optional. |
include_external |
Optional. |
authorization |
Required. A valid access token from the Spotify Accounts service. See the Web API authorization guide for more details. Defaults to |
include_meta_info |
Optional. Boolean indicating whether to include full result, with meta information such as |
Returns a data frame of results containing search data.
## Not run:
search_spotify('radiohead', 'artist')
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.