set_my_volume: Set the volume for the user’s current playback device.

View source: R/player.R

set_my_volumeR Documentation

Set the volume for the user’s current playback device.

Description

Set the volume for the user’s current playback device.

Usage

set_my_volume(volume_percent, device_id = NULL,
              authorization = get_spotify_authorization_code())

Arguments

volume_percent

Required. Integer. The volume to set. Must be a value from 0 to 100 inclusive.

device_id

Optional. The id of the device this command is targeting. If not supplied, the user’s currently active device is the target.

authorization

Required. A valid access token from the Spotify Accounts service. See the Web API authorization Guide for more details. Defaults to spotifyr::get_spotify_access_token(). The access token must have been issued on behalf of the current user.
The access token must have the user-modify-playback-state scope authorized in order to control playback.

Value

No return value.


tinyspotifyr documentation built on June 7, 2026, 5:06 p.m.