| start_my_playback | R Documentation |
Skips to previous track in the user’s queue.
start_my_playback(device_id = NULL, context_uri = NULL, uris = NULL,
offset = NULL, position_ms = NULL,
authorization = get_spotify_authorization_code())
device_id |
Optional. The id of the device this command is targeting. If not supplied, the user’s currently active device is the target. |
context_uri |
Optional. String of the Spotify URI of the context to play. Valid contexts are albums, artists, playlists. Example |
uris |
Optional. A character vector of the Spotify track URIs to play. For example: |
offset |
Optional. A named list indicating from where the context playback should start. Only available when |
position_ms |
Optional. Integer indicating from what position to start playback. Must be a positive number. Passing in a position that is greater than the length of the track will cause the player to start playing the next song. |
authorization |
Required. A valid access token from the Spotify Accounts service. See the Web API authorization Guide for more details. Defaults to |
No return value.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.