toggle_my_shuffle: Toggle shuffle on or off for user’s playback.

View source: R/player.R

toggle_my_shuffleR Documentation

Toggle shuffle on or off for user’s playback.

Description

Toggle shuffle on or off for user’s playback.

Usage

toggle_my_shuffle(state, device_id = NULL,
                  authorization = get_spotify_authorization_code())

Arguments

state

Required.
TRUE: Shuffle user's playback
FALSE Do not shuffle user's playback

device_id

Optional. The id of the device this command is targeting. If not supplied, the user’s currently active device is the target.

authorization

Required. A valid access token from the Spotify Accounts service. See the Web API authorization Guide for more details. Defaults to spotifyr::get_spotify_access_token(). The access token must have been issued on behalf of the current user.
The access token must have the user-modify-playback-state scope authorized in order to control playback.

Value

No return value.


tinyspotifyr documentation built on June 7, 2026, 5:06 p.m.