| unfollow_playlist | R Documentation |
Remove the current user as a follower of a playlist.
unfollow_playlist(playlist_id, authorization = get_spotify_authorization_code())
playlist_id |
Required. The Spotify ID of the playlist that is to be no longer followed. |
authorization |
Required. A valid access token from the Spotify Accounts service. See the Web API authorization Guide for more details. Defaults to |
No return value.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.