Learn R Programming

tinyspotifyr (version 0.2.3)

get_related_artists: Get Spotify catalog information about artists similar to a given artist. Similarity is based on analysis of the Spotify community’s listening history.

Description

Get Spotify catalog information about artists similar to a given artist. Similarity is based on analysis of the Spotify community’s listening history.

Usage

get_related_artists(id, authorization = get_spotify_access_token(),
                    include_meta_info = FALSE)

Value

Returns a data frame of results containing artist data. See https://developer.spotify.com/documentation/web-api for more information.

Arguments

id

The Spotify ID for the artist.

authorization

Required. A valid access token from the Spotify Accounts service. See the Web API authorization guide for more details. Defaults to spotifyr::get_spotify_access_token()

include_meta_info

Optional. Boolean indicating whether to include full result, with meta information such as "total", and "limit". Defaults to FALSE.