Get audio feature information for a single track identified by its unique Spotify ID.
get_track_audio_features(ids, authorization = get_spotify_access_token())Returns a data frame of results containing track audio features data. See https://developer.spotify.com/documentation/web-api for more information.
Required. A comma-separated list of the Spotify IDs of the tracks. Maximum: 100 IDs.
Required. A valid access token from the Spotify Accounts service. See the Web API authorization guide for more details. Defaults to spotifyr::get_spotify_access_token()
Deprecated. Spotify restricted GET /v1/audio-features
(HTTP 403) in November 2024; it no longer returns data for apps without
prior access.