Learn R Programming

tinyspotifyr (version 0.2.3)

is_uri: Check if a string matches the pattern of a Spotify URI

Description

Check if a string matches the pattern of a Spotify URI

Usage

is_uri(s)

Value

Returns a boolean.

Arguments

s

String to check