Learn R Programming

tinyspotifyr (version 0.2.3)

pause_my_playback: Pause playback on the user’s account.

Description

Pause playback on the user’s account.

Usage

pause_my_playback(device_id = NULL,
                  authorization = get_spotify_authorization_code())

Value

No return value.

Arguments

device_id

Optional. The id of the device this command is targeting. If not supplied, the user’s currently active device is the target.

authorization

Required. A valid access token from the Spotify Accounts service. See the Web API authorization Guide for more details. Defaults to spotifyr::get_spotify_access_token(). The access token must have been issued on behalf of the current user.
The access token must have the user-modify-playback-state scope authorized in order to control playback.