| reorder_replace_playlist_items | R Documentation |
Reorder or replace one or more items from a user’s playlist.
reorder_replace_playlist_items(playlist_id, uris,
authorization = get_spotify_authorization_code())
playlist_id |
Required. The Spotify ID for the playlist. |
uris |
Optional. A character vector of Spotify track URIs to add. For example |
authorization |
Required. A valid access token from the Spotify Accounts service. See the Web API authorization Guide for more details. Defaults to |
No return value. Tracks are added or reordered on playlist.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.